*-------------------------------------------------------------------------------

/*
TITLE: Tables for Cool to be Smart or Smart to be Cool

DESCRIPTION: Generates Tables 1-8, A.1

INPUT: 
bursztyn_egorov_jensen_restud.dta: 

OUTPUT: 
	table2.xls
	...
	table7.xls
	table8A.xls
	table8B.xls
	table8C.xls


Created Tables:

TABLE 1: BALANCE OF COVARIATES
TABLE 2: EFFECT OF PUBLIC TREATMENT ON SIGNUP DECISION
TABLE 3: EFFECT OF PUBLIC TREATMENT AND LOW PROBABILITY ON SIGNUP DECISION
TABLE 4: EFFECT OF HIGH PROBALITY ON SIGNUP: SPLIT BY GRADES (COOL-TO-BE-SMART SCHOOLS)
TABLE 5: EFFECT OF HIGH PROBALITY ON SIGNUP: SPLIT BY GRADES (SMART-TO-BE-COOL SCHOOL
TABLE 6: EFFECT OF PUBLIC TREATMENT ON SIGNUP DECISION: BY IMPORTANCE OF POPULARITY
TABLE 7: EFFECT OF PUBLIC TREATMENT AND LOW PROBABILITY ON SIGNUP DECISION: MEDIAN SPLIT OF CLASSROOMS BY AVERAGE OPINION ON IMPORTANCE OF BEING CONSIDERED SMART TO BE POPULAR
TABLE 8: LONGER-TERM OUTCOMES
APPENDIX TABLE A.1: BALANCE OF COVARIATES FOR SAMPLE REACHED IN THE SECOND VISIT TO THE LOWER INCOME SCHOOL

Note: for wild bootstrapping (boottest), seed was not set. Thus replication p-values
may differ slightly from the values reported in the paper. 
*/

*-------------------------------------------------------------------------------

clear
set more off
use "bursztyn_egorov_jensen_restud.dta"
mkdir tables

capture log close
capture log using "tables", replace

** Data manipulation
** ~~~~~~~~~~~~~~~~~~

gen private=(1-public)
gen privateXff=private*ffschools
gen publicXff=public*ffschools
gen privateXaw=private*(1-ffschools)
gen publicXaw=public*(1-ffschools)

* Interactions for popularity
gen popXprivate=imp_pop*(1-public)
gen popXpublic=imp_pop*public
gen notpopXprivate=(1-imp_pop)*(1-public)
gen notpopXpublic=(1-imp_pop)*public

gen smartXprivate=important_smart*(1-public)
gen smartXpublic=important_smart*public
gen notsmartXprivate=(1-important_smart)*(1-public)
gen notsmartXpublic=(1-important_smart)*public

* interactions for grades
gen high_grades=(grades<=2)
replace high_grades=. if grades==.
gen grades_low=1-high_grades

gen highprob=(1-lowp)
gen lowgradeXlow=grades_low*lowp
gen highgradeXlow=high_grades*lowp
gen lowgradeXhigh=grades_low*(1-lowp)
gen highgradeXhigh=high_grades*(1-lowp)

rename classroom classroom_id


** Tables:
** ~~~~~~~

* This code is for generating the regression tables in the paper

******************************** // ********************************
* TABLES
******************************** // ********************************


******************************** Table 1: Balance of Covariates

foreach var of varlist male age hispanic {
	* creates each row of the regression in table 1
	reg `var' privateXhigh privateXlow publicXhigh publicXlow , robust noc
	foreach var2 of varlist privateXhigh privateXlow publicXhigh publicXlow {
		sum `var' if `var2'==1
	}
	* the fifth column p-value regression for each condition
	test privateXhigh=privateXlow=publicXhigh=publicXlow

}

******************************** Table 2: Effect of Public Treatment on Signup Decision

** Column 1 **
xi: reg takeup public if school=="StbC" , r
outreg2 using tables/table2.xls, bdec(4) sdec(3) se  bracket replace

** Column 2 **
xi: reg takeup public age male hispanic if school=="StbC", r
outreg2 using tables/table2.xls, bdec(4) sdec(3) se  bracket append

** Column 3 **
xi: reg takeup public  age male hispanic i.classroom i.surv if school=="StbC", r
outreg2 using tables/table2.xls, bdec(4) sdec(3) se  bracket append

** Column 4 **
xi: reg takeup public if school!="StbC" , r
outreg2 using tables/table2.xls, bdec(4) sdec(3) se  bracket append

** Column 5 **
xi: reg takeup public age male hispanic if school!="StbC", r
outreg2 using tables/table2.xls, bdec(4) sdec(3) se  bracket append

** Column 6 **
xi: reg takeup public  age male hispanic i.classroom i.surv if school!="StbC", r
outreg2 using tables/table2.xls, bdec(4) sdec(3) se  bracket append

***THE FOLLOWING REPLICATE THE ABOVE, BUT WITH INTERACTIONS INSTEAD OF SPLIT SAMPLE
gen smart_to_be_cool = school=="StbC"

xi: reg takeup public##smart_to_be_cool, r
outreg2 using tables/table2_interactions.xls, bdec(4) sdec(3) se  bracket replace

xi: reg takeup public##smart_to_be_cool age##smart_to_be_cool male##smart_to_be_cool hispanic##smart_to_be_cool, r
outreg2 using tables/table2_interactions.xls, bdec(4) sdec(3) se  bracket append

xi: reg takeup public##smart_to_be_cool  age##smart_to_be_cool male##smart_to_be_cool hispanic##smart_to_be_cool i.classroom i.surv, r
outreg2 using tables/table2_interactions.xls, bdec(4) sdec(3) se  bracket append


******************************** Table 3: EFFECT OF PUBLIC TREATMENT AND LOW PROBABILITY ON SIGNUP DECISION

** Column 1 **
xi: reg takeup lowprob public publicXlow if school=="StbC" , r
outreg2 using tables/table3.xls, bdec(4) sdec(3) se  bracket replace
test low+publicXlow==0
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow+lowprob=0, cluster(classroom) weight(webb) boott(wild)

** Column 2 **
xi: reg takeup lowprob public publicXlow age male hispanic if school=="StbC", r
outreg2 using tables/table3.xls, bdec(4) sdec(3) se  bracket append
test low+publicXlow==0
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow+lowprob=0, cluster(classroom) weight(webb) boott(wild)

** Column 3 **
xi: reg takeup lowprob public publicXlow  age male hispanic i.classroom i.surv if school=="StbC", r
outreg2 using tables/table3.xls, bdec(4) sdec(3) se  bracket append
test low+publicXlow==0
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow+lowprob=0, cluster(classroom) weight(webb) boott(wild)

** Column 4 **
xi: reg takeup lowprob public publicXlow if school!="StbC" , r
outreg2 using tables/table3.xls, bdec(4) sdec(3) se  bracket append
test low+publicXlow==0
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow+lowprob=0, cluster(classroom) weight(webb) boott(wild)

** Column 5 **
xi: reg takeup lowprob public publicXlow age male hispanic if school!="StbC", r
outreg2 using tables/table3.xls, bdec(4) sdec(3) se  bracket append
test low+publicXlow==0
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow+lowprob=0, cluster(classroom) weight(webb) boott(wild)

** Column 6 **
xi: reg takeup lowprob public publicXlow  age male hispanic i.classroom i.surv if school!="StbC", r
outreg2 using tables/table3.xls, bdec(4) sdec(3) se  bracket append
test low+publicXlow==0
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow+lowprob=0, cluster(classroom) weight(webb) boott(wild)

***THE FOLLOWING REPLICATE THE ABOVE, BUT WITH INTERACTIONS INSTEAD OF SPLIT SAMPLE
xi: reg takeup lowprob##smart_to_be_cool public##smart_to_be_cool publicXlow##smart_to_be_cool, r
outreg2 using tables/table3_interactions.xls, bdec(4) sdec(3) se  bracket replace

xi: reg takeup lowprob##smart_to_be_cool public##smart_to_be_cool publicXlow##smart_to_be_cool age##smart_to_be_cool male##smart_to_be_cool hispanic##smart_to_be_cool, r
outreg2 using tables/table3_interactions.xls, bdec(4) sdec(3) se  bracket append

xi: reg takeup lowprob##smart_to_be_cool public##smart_to_be_cool publicXlow##smart_to_be_cool age##smart_to_be_cool male##smart_to_be_cool hispanic##smart_to_be_cool i.classroom i.surv, r
outreg2 using tables/table3_interactions.xls, bdec(4) sdec(3) se  bracket append


******************************** Table 4:  EFFECT OF HIGH PROBABILITY ON SIGNUP: SPLIT BY GRADES (COOL-TO-BE-SMART SCHOOLS)


** Column 1 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow   if school!="StbC" & public==1 , r
outreg2 using tables/table4.xls, bdec(4) sdec(3) se  bracket replace
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 2 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow  age male hispanic if school!="StbC" & public==1 , r
outreg2 using tables/table4.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 3 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow   age male hispanic i.classroom i.surv if school!="StbC" & public==1 , r
outreg2 using tables/table4.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 4 **
xi: reg takeup highprob lowgradeXhigh  lowgradeXlow  if school!="StbC" & public==0 , r
outreg2 using tables/table4.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 5 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow  age male hispanic if school!="StbC" & public==0 , r
outreg2 using tables/table4.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 6 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow   age male hispanic i.classroom i.surv if school!="StbC" & public==0 , r
outreg2 using tables/table4.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

***THE FOLLOWING REPLICATE THE ABOVE, BUT WITH INTERACTIONS FOR PUBLIC/PRIVATE INSTEAD OF SPLIT SAMPLE
xi: reg takeup highprob##public lowgradeXlow##public lowgradeXhigh##public    if school!="StbC", r
outreg2 using tables/table4_interactions.xls, bdec(4) sdec(3) se  bracket replace

xi: reg takeup highprob##public lowgradeXlow##public lowgradeXhigh##public age##public male##public hispanic##public if school!="StbC", r
outreg2 using tables/table4_interactions.xls, bdec(4) sdec(3) se  bracket append

xi: reg takeup highprob##public lowgradeXlow##public lowgradeXhigh##public    age##public male##public hispanic##public i.classroom i.surv if school!="StbC", r
outreg2 using tables/table4_interactions.xls, bdec(4) sdec(3) se  bracket append



******************************** Table 5:  EFFECT OF HIGH PROBABILITY ON SIGNUP: SPLIT BY GRADES (SMART-TO-BE-COOL SCHOOL)


** Column 1 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow  if school=="StbC" & public==1 , r
outreg2 using tables/table5.xls, bdec(4) sdec(3) se  bracket replace
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 2 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow  age male hispanic if school=="StbC" & public==1 , r
outreg2 using tables/table5.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 3 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow   age male hispanic i.classroom i.surv if school=="StbC" & public==1 , r
outreg2 using tables/table5.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 4 **
xi: reg takeup highprob lowgradeXhigh  lowgradeXlow  if school=="StbC" & public==0 , r
outreg2 using tables/table5.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 5 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow  age male hispanic if school=="StbC" & public==0 , r
outreg2 using tables/table5.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

** Column 6 **
xi: reg takeup highprob lowgradeXhigh lowgradeXlow   age male hispanic i.classroom i.surv if school=="StbC" & public==0 , r
outreg2 using tables/table5.xls, bdec(4) sdec(3) se  bracket append
boottest  lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh-highprob=0, cluster(classroom) weight(webb) boott(wild)
boottest  lowgradeXlow-lowgradeXhigh=0, cluster(classroom) weight(webb) boott(wild)

***THE FOLLOWING REPLICATE THE ABOVE, BUT WITH INTERACTIONS FOR PUBLIC/PRIVATE INSTEAD OF SPLIT SAMPLE
xi: reg takeup highprob##public lowgradeXlow##public lowgradeXhigh##public    if school!="StbC", r
outreg2 using tables/table5_interactions.xls, bdec(4) sdec(3) se  bracket replace

xi: reg takeup highprob##public lowgradeXlow##public lowgradeXhigh##public age##public male##public hispanic##public if school!="StbC", r
outreg2 using tables/table5_interactions.xls, bdec(4) sdec(3) se  bracket append

xi: reg takeup highprob##public lowgradeXlow##public lowgradeXhigh##public    age##public male##public hispanic##public i.classroom i.surv if school!="StbC", r
outreg2 using tables/table5_interactions.xls, bdec(4) sdec(3) se  bracket append


******************************** Table 6:  EFFECT OF PUBLIC TREATMENT ON SIGNUP DECISION: BY IMPORTANCE OF POPULARITY

** Column 1 **
reg takeup  popXpublic  notpopXpublic imp_pop if school=="StbC"  , robust 
outreg2 using tables/table6.xls, bdec(4) sdec(3) se  bracket replace
boottest  popXpublic=0, cluster(classroom) weight(webb) boott(wild)
boottest  notpopXpublic=0, cluster(classroom) weight(webb) boott(wild)

** Column 2 **	
reg takeup  popXpublic  notpopXpublic imp_pop age male hispanic if school=="StbC"  , robust 
outreg2 using tables/table6.xls, bdec(4) sdec(3) se  bracket append
boottest  popXpublic=0, cluster(classroom) weight(webb) boott(wild)
boottest  notpopXpublic=0, cluster(classroom) weight(webb) boott(wild)

** Column 3 **
reg takeup  popXpublic  notpopXpublic imp_pop age male hispanic i.classroom i.surv if school=="StbC"  , robust 
outreg2 using tables/table6.xls, bdec(4) sdec(3) se  bracket append
boottest  popXpublic=0, cluster(classroom) weight(webb) boott(wild)
boottest  notpopXpublic=0, cluster(classroom) weight(webb) boott(wild)

** Column 4 **
reg takeup  popXpublic  notpopXpublic imp_pop if school!="StbC"  , robust 
outreg2 using tables/table6.xls, bdec(4) sdec(3) se  bracket append
boottest  popXpublic=0, cluster(classroom) weight(webb) boott(wild)
boottest  notpopXpublic=0, cluster(classroom) weight(webb) boott(wild)

** Column 5 **
reg takeup  popXpublic  notpopXpublic imp_pop age male hispanic if school!="StbC"  , robust 
outreg2 using tables/table6.xls, bdec(4) sdec(3) se  bracket append
boottest  popXpublic=0, cluster(classroom) weight(webb) boott(wild)
boottest  notpopXpublic=0, cluster(classroom) weight(webb) boott(wild)

** Column 6 **
reg takeup  popXpublic  notpopXpublic imp_pop age male hispanic i.classroom i.surv if school!="StbC"  , robust 
outreg2 using tables/table6.xls, bdec(4) sdec(3) se  bracket append
boottest  popXpublic=0, cluster(classroom) weight(webb) boott(wild)
boottest  notpopXpublic=0, cluster(classroom) weight(webb) boott(wild)

***THE FOLLOWING REPLICATE THE ABOVE, BUT WITH INTERACTIONS INSTEAD OF SPLIT SAMPLE

reg takeup  popXpublic##smart_to_be_cool  notpopXpublic##smart_to_be_cool imp_pop##smart_to_be_cool, robust 
outreg2 using tables/table6_interactions.xls, bdec(4) sdec(3) se  bracket replace

reg takeup  popXpublic##smart_to_be_cool  notpopXpublic##smart_to_be_cool imp_pop##smart_to_be_cool age##smart_to_be_cool male##smart_to_be_cool hispanic##smart_to_be_cool, robust 
outreg2 using tables/table6_interactions.xls, bdec(4) sdec(3) se  bracket append

reg takeup  popXpublic##smart_to_be_cool  notpopXpublic##smart_to_be_cool imp_pop##smart_to_be_cool age##smart_to_be_cool male##smart_to_be_cool hispanic##smart_to_be_cool i.classroom i.surv, robust 
outreg2 using tables/table6_interactions.xls, bdec(4) sdec(3) se  bracket append

***************************TABLE 7: EFFECT OF PUBLIC TREATMENT AND LOW PROBABILITY ON SIGNUP DECISION: MEDIAN SPLIT

** Column 1 **
xi: reg takeup lowpro public publicXlow if high_smart==0 , r
outreg2 using tables/table7.xls, bdec(4) sdec(3) se  bracket replace
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)

** Column 2 **
xi: reg takeup lowpro public publicXlow age male hispanic if high_smart==0, r
outreg2 using tables/table7.xls, bdec(4) sdec(3) se  bracket append
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)

** Column 3 **
xi: reg takeup lowpro public publicXlow  age male hispanic i.classroom i.surv if high_smart==0, r
outreg2 using tables/table7.xls, bdec(4) sdec(3) se  bracket append
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)

** Column 4 **
xi: reg takeup lowpro public publicXlow if high_smart==1 , r
outreg2 using tables/table7.xls, bdec(4) sdec(3) se  bracket append
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)

** Column 5 **
xi: reg takeup lowpro public publicXlow age male hispanic if high_smart==1, r
outreg2 using tables/table7.xls, bdec(4) sdec(3) se  bracket append
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)

** Column 6 **
xi: reg takeup lowpro public publicXlow  age male hispanic i.classroom i.surv if high_smart==1, r
outreg2 using tables/table7.xls, bdec(4) sdec(3) se  bracket append
boottest  public=0, cluster(classroom) weight(webb) boott(wild)
boottest  publicXlow=0, cluster(classroom) weight(webb) boott(wild)

************************************* Table 8:  LONGER-TERM OUTCOMES

replace offered=0 if offered==.

gen high=(1-lowpro)

*PANEL A: private condition
reg taken_a high if public==0, r
	outreg2 using tables/table8A.xls, bdec(4) sdec(3) se  bracket replace
boottest  high=0, cluster(classroom) weight(webb) boott(wild)

reg taken_a high male age hispanic if public==0, r
	outreg2 using tables/table8A.xls, bdec(4) sdec(3) se  bracket append
boottest  high=0, cluster(classroom) weight(webb) boott(wild)

reg taken_a high male age hispanic i.classroom i.surv if public==0, r
	outreg2 using tables/table8A.xls, bdec(4) sdec(3) se  bracket append
boottest  high=0, cluster(classroom) weight(webb) boott(wild)
			
reg junior high if public==0, r
	outreg2 using tables/table8A.xls, bdec(4) sdec(3) se  bracket append
boottest  high=0, cluster(classroom) weight(webb) boott(wild)

reg junior high male age hispanic if public==0, r
	outreg2 using tables/table8A.xls, bdec(4) sdec(3) se  bracket append
boottest  high=0, cluster(classroom) weight(webb) boott(wild)

reg junior high male age hispanic i.classroom i.surv if public==0, r
	outreg2 using tables/table8A.xls, bdec(4) sdec(3) se  bracket append
boottest  high=0, cluster(classroom) weight(webb) boott(wild)

*PANEL B: full sample
reg taken_a private , r
	outreg2 using tables/table8B.xls, bdec(4) sdec(3) se  bracket replace
boottest  private=0, cluster(classroom) weight(webb) boott(wild)

reg taken_a private male age hispanic , r
	outreg2 using tables/table8B.xls, bdec(4) sdec(3) se  bracket append
boottest  private=0, cluster(classroom) weight(webb) boott(wild)

reg taken_a private male age hispanic i.classroom i.surv , r
	outreg2 using tables/table8B.xls, bdec(4) sdec(3) se  bracket append
boottest  private=0, cluster(classroom) weight(webb) boott(wild)
			
reg junior private , r
	outreg2 using tables/table8B.xls, bdec(4) sdec(3) se  bracket append
boottest  private=0, cluster(classroom) weight(webb) boott(wild)

reg junior private male age hispanic , r
	outreg2 using tables/table8B.xls, bdec(4) sdec(3) se  bracket append
boottest  private=0, cluster(classroom) weight(webb) boott(wild)

reg junior private male age hispanic i.classroom i.surv , r
	outreg2 using tables/table8B.xls, bdec(4) sdec(3) se  bracket append
boottest  private=0, cluster(classroom) weight(webb) boott(wild)
	
	
*PANEL C: Sample of students who signed up for the prep package lottery

reg taken_a offered if takeup==1, r
outreg2 using tables/table8C.xls, bdec(4) sdec(3) se  bracket replace
boottest  offered=0, cluster(classroom) weight(webb) boott(wild)

reg taken_a offered male age hispanic if takeup==1, r
outreg2 using tables/table8C.xls, bdec(4) sdec(3) se  bracket append
boottest  offered=0, cluster(classroom) weight(webb) boott(wild)

reg taken_a offered male age hispanic i.classroom i.surv if takeup==1, r
outreg2 using tables/table8C.xls, bdec(4) sdec(3) se  bracket append
boottest  offered=0, cluster(classroom) weight(webb) boott(wild)

reg junior_y offered if takeup==1, r 
outreg2 using tables/table8C.xls, bdec(4) sdec(3) se  bracket append
boottest  offered=0, cluster(classroom) weight(webb) boott(wild)

reg junior_y offered male age hispanic if takeup==1, r
outreg2 using tables/table8C.xls, bdec(4) sdec(3) se  bracket append
boottest  offered=0, cluster(classroom) weight(webb) boott(wild)

reg junior_y offered male age hispanic i.classroom i.surv if takeup==1, r
outreg2 using tables/table8C.xls, bdec(4) sdec(3) se  bracket append
boottest  offered=0, cluster(classroom) weight(webb) boott(wild)


**************** Appendix Table A.1 balance of covariates in the second visit to lower income

foreach var of varlist age male hispanic {
	foreach var2 of varlist privateXhigh privateXlow publicXhigh publicXlow {
		sum `var' if `var2'==1 & missing==0 & school=="StbC"
	}
	reg `var' privateXhigh privateXlow publicXhigh publicXlow if missing==0 & school=="StbC", robust noc
	test privateXhigh=privateXlow=publicXhigh=publicXlow
}

